setwd("<YOUR DIRECTORY>")

# read data
sample1 <- read.csv(file="responses.csv", header=TRUE, sep=";", quote="\"", na.strings=c(""), stringsAsFactors=FALSE)
nrow(sample1)
# 998 (two removed during survey)

# response rate
completed <- sample1[sample1$unipark_code==31 | sample1$unipark_code==32, ]
nrow(completed)
# 122
nrow(completed)/1000*100
# 12.2%

summary(completed$age)
# Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 0.00   26.00   29.00   28.94   33.75   54.00 
sd(completed$age)
# 9.062956

library(car)
completed$gender <- car::recode(completed$gender,
                     "1='male';
                      2='female';
                      else=NA;")
sort(table(completed$gender), decreasing=TRUE)
# male female 
#  115      1 

completed$main_role <- car::recode(completed$main_role, 
                         "1='Software developer';
                          2='Software tester';
                          3='Software architect';
                          4='Administrator';
                          5='Manager';
                          6='Designer';
                          7='Consultant';
                          8='Researcher';
                          9='Student';
                          10='Other';
                          else=NA;")
sort(table(completed$main_role), decreasing=TRUE)
#Software developer Software architect              Other         Consultant            Manager         Researcher            Student 
#                82                 17                  6                  5                  5                  5                  2 
nrow(completed[completed$main_role=="Software developer",])/nrow(completed)*100
# 67.21311
nrow(completed[completed$main_role=="Software architect",])/nrow(completed)*100
# 13.93443

summary(completed$work_time_dev)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   0.00   50.00   80.00   70.45   90.00  100.00 
sd(completed$work_time_dev)
# 26.36868

summary(completed$experience_general)
# Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 2.00    7.00   10.00   11.84   15.00   35.00 
sd(completed$experience_general)
# 6.7314

summary(completed$expertise_general)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 2.000   4.000   5.000   4.828   6.000   6.000 

completed$purpose_github <- car::recode(completed$purpose_github, 
                         "1='I dont use GitHub.';
                          2='I use GitHub only for private projects.';
                          3='I use GitHub only for work-related projects.';
                          4='I use GitHub for both private and work-related projects.';
                          else=NA;")
sort(table(completed$purpose_github), decreasing=TRUE)
# I use GitHub for both private and work-related projects.  I use GitHub only for private projects. 
# 80                                                        34 
# I use GitHub only for work-related projects.              I dont use GitHub. 
# 6                                                         2
80/122*100
# 65.57377
34/122*100
# 27.86885
6/122*100
# 4.918033
2/122*100
# 1.639344

completed$purpose_stackoverflow <- car::recode(completed$purpose_stackoverflow, 
                                       "1='I dont use Stack Overflow.';
                                        2='I use Stack Overflow only for private projects.';
                                        3='I use Stack Overflow only for work-related projects.';
                                        4='I use Stack Overflow for both private and work-related projects.';
                                        else=NA;")
sort(table(completed$purpose_stackoverflow), decreasing=TRUE)
# I use Stack Overflow for both private and work-related projects.  I dont use Stack Overflow. 
# 119                                                               1 
# I use Stack Overflow only for private projects.                   I use Stack Overflow only for work-related projects. 
# 1                                                                 1 
119/122*100
# 97.54098

completed$snippet_last_time <- car::recode(completed$snippet_last_time, 
                                       "1='Today';
                                        2='Not more than one week ago';
                                        3='Not more than one month ago';
                                        4='Not more than one year ago';
                                        5='More than one year ago';
                                        6='Never';
                                        else=NA;")
sort(table(completed$snippet_last_time), decreasing=TRUE)
# Not more than one month ago  Not more than one week ago  Not more than one year ago  Today 
# 49                           37                          19                          10 
# More than one year ago       Never 
# 5                            1 
49/122*100
# 40.16393
37/122*100
# 30.32787
19/122*100
# 15.57377
10/122*100
# 8.196721
(49+37+10)/122*100
# 78.68852
(37+10)/122*100
# 38.52459

completed$snippet_attribution <- car::recode(completed$snippet_attribution, 
                                       "1='I added a source code comment referring to Stack Overflow in general.';
                                        2='I added a source code comment with a link to the Stack Overflow question/answer.';
                                        3='I just copied/adapted the code snippet without any reference.';
                                        4='Other';
                                        else=NA;")
sort(table(completed$snippet_attribution), decreasing=TRUE)
# I just copied/adapted the code snippet without any reference. 
# 60 
# I added a source code comment with a link to the Stack Overflow question/answer. 
# 49 
# Other 
# 7 
# I added a source code comment referring to Stack Overflow in general. 
# 4
60/122*100
# 49.18033
49/122*100
# 40.16393
(7+4)/122*100
# 9.016393
completed$snippet_attribution_other <- car::recode(completed$snippet_attribution_other, 
                                             "-99=NA;
                                              'NA'=NA;
                                              'N/A'=NA;")
completed$snippet_attribution_other[!is.na(completed$snippet_attribution_other)]
